@@ -50,7 +50,7 @@ class GerritGroupMembers:
             account_id = result.get("_account_id")
             return self.gerrit.accounts.get(account_id)
         except requests.exceptions.HTTPError as error:
-            if error.response.status_code in (404, 400):
+            if error.response.status_code == 404:
                 message = f"Group member {account} does not exist"
                 logger.error(message)
                 raise GroupMemberNotFoundError(message)
