@@ -1,22 +1,21 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
+import six.moves.urllib.parse as urlparse
 from requests import Session
 from requests.adapters import HTTPAdapter
-import six.moves.urllib.parse as urlparse
 from gerrit.utils.exceptions import (
     NotAllowedError,
     ValidationError,
     AuthError,
     UnauthorizedError,
-    NotFoundError,
     ConflictError,
     ClientError,
     ServerError,
 )
 
 
-class Requester(object):
+class Requester:
 
     """
     A class which carries out HTTP requests. You can replace this
@@ -54,7 +53,7 @@ class Requester(object):
         """
         Updates scheme of given url to the one used in Gerrit base_url.
         """
-        if self.base_scheme and not url.startswith("%s://" % self.base_scheme):
+        if self.base_scheme and not url.startswith(f"{self.base_scheme}://"):
             url_split = urlparse.urlsplit(url)
             url = urlparse.urlunsplit(
                 [
@@ -83,11 +82,15 @@ class Requester(object):
             request_kwargs["auth"] = (self.username, self.password)
 
         if params:
-            assert isinstance(params, dict), f"Params must be a dict, got {repr(params)}"
+            if not isinstance(params, dict):
+                raise ValueError(f"Params must be a dict, got {repr(params)}")
+
             request_kwargs["params"] = params
 
         if headers:
-            assert isinstance(headers, dict), f"headers must be a dict, got {repr(headers)}"
+            if not isinstance(headers, dict):
+                raise ValueError(f"headers must be a dict, got {repr(headers)}")
+
             request_kwargs["headers"] = headers
 
         if self.AUTH_COOKIE:
@@ -118,6 +121,7 @@ class Requester(object):
         headers=None,
         allow_redirects=True,
         stream=False,
+        raise_for_status: bool = True,
         **kwargs
     ):
         """
@@ -126,6 +130,7 @@ class Requester(object):
         :param headers:
         :param allow_redirects:
         :param stream:
+        :param raise_for_status:
         :param kwargs:
         :return:
         """
@@ -136,7 +141,10 @@ class Requester(object):
             stream=stream,
             **kwargs
         )
-        return self.confirm_status(self.session.get(self._update_url_scheme(url), **request_kwargs))
+        response = self.session.get(self._update_url_scheme(url), **request_kwargs)
+        if raise_for_status:
+            self.confirm_status(response)
+        return response
 
     def post(
         self,
@@ -147,6 +155,7 @@ class Requester(object):
         files=None,
         headers=None,
         allow_redirects=True,
+        raise_for_status: bool = True,
         **kwargs
     ):
         """
@@ -157,6 +166,7 @@ class Requester(object):
         :param files:
         :param headers:
         :param allow_redirects:
+        :param raise_for_status:
         :param kwargs:
         :return:
         """
@@ -169,7 +179,10 @@ class Requester(object):
             allow_redirects=allow_redirects,
             **kwargs
         )
-        return self.confirm_status(self.session.post(self._update_url_scheme(url), **request_kwargs))
+        response = self.session.post(self._update_url_scheme(url), **request_kwargs)
+        if raise_for_status:
+            self.confirm_status(response)
+        return response
 
     def put(
         self,
@@ -180,6 +193,7 @@ class Requester(object):
         files=None,
         headers=None,
         allow_redirects=True,
+        raise_for_status: bool = True,
         **kwargs
     ):
         """
@@ -190,6 +204,7 @@ class Requester(object):
         :param files:
         :param headers:
         :param allow_redirects:
+        :param raise_for_status:
         :param kwargs:
         :return:
         """
@@ -202,23 +217,30 @@ class Requester(object):
             allow_redirects=allow_redirects,
             **kwargs
         )
-        return self.confirm_status(self.session.put(self._update_url_scheme(url), **request_kwargs))
+        response = self.session.put(self._update_url_scheme(url), **request_kwargs)
+        if raise_for_status:
+            self.confirm_status(response)
+        return response
 
-    def delete(self, url, headers=None, allow_redirects=True, **kwargs):
+    def delete(self, url, headers=None, allow_redirects=True, raise_for_status: bool = True, **kwargs):
         """
         :param url:
         :param headers:
         :param allow_redirects:
+        :param raise_for_status:
         :param kwargs:
         :return:
         """
         request_kwargs = self.get_request_dict(
             headers=headers, allow_redirects=allow_redirects, **kwargs
         )
-        return self.confirm_status(self.session.delete(self._update_url_scheme(url), **request_kwargs))
+        response = self.session.delete(self._update_url_scheme(url), **request_kwargs)
+        if raise_for_status:
+            self.confirm_status(response)
+        return response
 
     @staticmethod
-    def confirm_status(res):
+    def confirm_status(res):  # pylint: disable=too-many-branches
         """
         check response status code
         :param res:
@@ -243,11 +265,10 @@ class Requester(object):
         elif 500 <= res.status_code < 600:
             http_error_msg = f"{res.status_code} Server Error: {reason} for url: {res.url}"
 
-        if res.status_code < 300:
-            # OK, return http response
-            return res
+        if not http_error_msg:
+            return
 
-        elif res.status_code == 400:
+        if res.status_code == 400:
             # Validation error
             raise ValidationError(http_error_msg)
 
@@ -261,7 +282,7 @@ class Requester(object):
 
         elif res.status_code == 404:
             # Not Found
-            raise NotFoundError(http_error_msg)
+            res.raise_for_status()
 
         elif res.status_code == 405:
             # Method Not Allowed
